pub trait BrowserBehaviorAdapter {
// Required method
fn apply(&self, config: &mut BrowserConfig) -> AppliedBehaviorPlan;
}Expand description
Trait for behavior adapters that can mutate a browser config.
Required Methods
Sourcefn apply(&self, config: &mut BrowserConfig) -> AppliedBehaviorPlan
fn apply(&self, config: &mut BrowserConfig) -> AppliedBehaviorPlan
Apply behavior to config and return the derived runtime plan.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".