pub enum WaitUntil {
DomContentLoaded,
NetworkIdle,
Selector(String),
}Expand description
Example
use stygian_browser::page::WaitUntil;Specifies what condition to wait for after a page navigation.
Variants
DomContentLoaded
Fires when the initial HTML is fully parsed, without waiting for subresources such as images and stylesheets to finish loading.
NetworkIdle
Selector(String)