BrowserHandle

Struct BrowserHandle 

pub struct BrowserHandle { /* private fields */ }
An acquired browser from the pool.

Call BrowserHandle::release after use to return the instance to the idle queue. If dropped without releasing, the browser is shut down and the pool slot freed.

Implementations

Source

impl BrowserHandle

pub const fn browser(&self) -> Option<&BrowserInstance>

Borrow the underlying BrowserInstance.

Returns None if the handle has already been released via release.

pub const fn browser_mut(&mut self) -> Option<&mut BrowserInstance>

Mutable borrow of the underlying BrowserInstance.

Returns None if the handle has already been released via release.

pub fn context_id(&self) -> Option<&str>

The context that owns this handle, if scoped via BrowserPool::acquire_for.

Returns None for handles obtained with BrowserPool::acquire.

pub async fn release(self)

Return the browser to the pool.

If the instance is unhealthy or the pool is full it will be disposed.