pub async fn run_akamai(pool: &Arc<BrowserPool>) -> ValidationResultExpand description
Run the Akamai validator on an Akamai-protected site (e.g., FedEx).
Navigates to the FedEx tracking page and checks if the page loads
without bot detection.
pub async fn run_akamai(pool: &Arc<BrowserPool>) -> ValidationResultRun the Akamai validator on an Akamai-protected site (e.g., FedEx).
Navigates to the FedEx tracking page and checks if the page loads
without bot detection.