pub async fn run_cloudflare(pool: &Arc<BrowserPool>) -> ValidationResultExpand description
Run the Cloudflare validator on a CF-protected site.
Navigates to a Cloudflare-protected page and checks if the page loads without a challenge block.
pub async fn run_cloudflare(pool: &Arc<BrowserPool>) -> ValidationResultRun the Cloudflare validator on a CF-protected site.
Navigates to a Cloudflare-protected page and checks if the page loads without a challenge block.