pub async fn run_creepjs(pool: &Arc<BrowserPool>) -> ValidationResultExpand description
Run the CreepJS observatory validator.
Navigates to CreepJS, waits for results, extracts the trust score, and
checks if it is > 50%.
pub async fn run_creepjs(pool: &Arc<BrowserPool>) -> ValidationResultRun the CreepJS observatory validator.
Navigates to CreepJS, waits for results, extracts the trust score, and
checks if it is > 50%.