BrowserBehaviorAdapter

Trait BrowserBehaviorAdapter 

pub trait BrowserBehaviorAdapter {
    // Required method
    fn apply(&self, config: &mut BrowserConfig) -> AppliedBehaviorPlan;
}
Trait for behavior adapters that can mutate a browser config.

Required Methods

fn apply(&self, config: &mut BrowserConfig) -> AppliedBehaviorPlan

Apply behavior to config and return the derived runtime plan.

Implementors