pub enum BrowserError {
LaunchFailed {
reason: String,
},
CdpError {
operation: String,
message: String,
},
PoolExhausted {
active: usize,
max: usize,
},
Timeout {
operation: String,
duration_ms: u64,
},
NavigationFailed {
url: String,
reason: String,
},
ScriptExecutionFailed {
script: String,
reason: String,
},
ConnectionError {
url: String,
reason: String,
},
ConfigError(String),
Io(Error),
}Expand description
Errors that can occur during browser automation.
Every variant carries enough structured context to decide on a retry policy or surface a useful diagnostic message without string-parsing.
Variants
LaunchFailed
Browser process failed to start.
CdpError
Chrome DevTools Protocol (CDP) operation failed.
Fields
PoolExhausted
All pool slots are occupied and the wait timeout elapsed.
Timeout
An operation exceeded its configured timeout.
Fields
Page navigation failed.
ScriptExecutionFailed
JavaScript evaluation failed.
ConnectionError
WebSocket / transport connection error.
ConfigError(String)
Invalid configuration value.
Io(Error)
Underlying I/O error.